@@ -23,6 +23,7 @@
 #include <qclipboard.h>
 #include <QCloseEvent>
 #include <qcursor.h>
+#include <QDebug>
 #include <QDesktopServices>
 #include <QDir>
 #include <qicon.h>
@@ -37,14 +38,10 @@
 #include <QTimer>
 #include <QToolBar>
 #include <QWhatsThis>
-#include <QtDebug>
-
-
 
 // NApplication
 #include "applicationfactory.h"
 #include "runcommand.h"
-#include "runcommandforoutput.h"
 #include "gainroot.h"
 
 // namespace NPlugin 
@@ -56,7 +53,6 @@
 #include "plugincontainer.h"
 #include "pluginmanager.h"
 #include "packagenotfoundexception.h"
-#include "plugincompare.h"
 #include "settingsdlg.h"
 #include "packagenameplugin.h"
 #include "scoredisplayplugin.h"
@@ -64,9 +60,6 @@
 // NXml
 #include "xmldata.h"
 
-// NException
-#include "exception.h"
-
 #include "extalgorithm.h"
 
 
@@ -99,6 +92,20 @@ template class LesserPriority<NPlugin::InformationPlugin>;
 template class LesserPriority<NPlugin::ShortInformationPlugin>;
 
 
+
+QString searchFileInPathList(const QStringList& relativePaths, QString fileName, QString resourceTypeName) {
+    for(QString path : relativePaths) {
+        if (QFileInfo::exists(path + "/" + fileName)) {
+            // rest of the code seems to require trailing / so we give it to them for now..
+            return path + "/";
+        }
+    }
+    qWarning() << "Could not find " << resourceTypeName << " directory. " << "It must be located in one of: "
+               << relativePaths.join(", ");
+    return "";
+}
+
+
 PackageSearchImpl::PackageSearchImpl( QWidget* parent, const char* name, Qt::WindowFlags fl )
 : QMainWindow(parent, fl), _DETAILS_INFORMATION_PRIORITY(2), _network(NUtil::NetworkSettings::SYSTEM_PROXY)
 {
@@ -189,33 +196,22 @@ PackageSearchImpl::~PackageSearchImpl()
 void PackageSearchImpl::initDirectories()
 {
 	// search for doc path
-	if  ( QFile("../doc/content.html").exists() )
-	{
-		QDir docDir = QDir::current();
-		docDir.cd("../doc/");
-		_docDir = docDir.absolutePath()+"/";
-	}
-	else if ( QFile("doc/content.html").exists() )
-	{
-		QDir docDir = QDir::current();
-		docDir.cd("doc/");
-		_docDir = docDir.absolutePath()+"/";
-	}
-	else if ( QFile("/usr/share/doc/packagesearch/content.html").exists() )
-		_docDir = "/usr/share/doc/packagesearch/";
-	else
-		cerr << "Could not find doc directory. It must be located at "
-		"/usr/share/doc/packagesearch/, ../doc/ or doc/."<<endl;
-	// search for icon path
-	if ( QFile("../icons/packagesearch.png").exists() )
-		_iconDir = "../icons/";
-	else if ( QFile("icons/packagesearch.png").exists() )
-		_iconDir = "icons/";
-	else if ( QFile("/usr/share/pixmaps/packagesearch/packagesearch.png").exists() )
-		_iconDir = "/usr/share/pixmaps/packagesearch/";
-	else
-		cerr << "Could not find icon directory. It must located at "
-			"/usr/share/pixmaps/packagesearch, ../icons/ or icons/."<<endl;
+
+    QStringList docPaths = {
+        "../doc",
+        "doc",
+        "../packagesearch/doc",
+        "/usr/share/doc/packagesearch"
+    };
+    _docDir = searchFileInPathList(docPaths, "content.html", "doc");
+
+    QStringList iconPaths = {
+        "../icons",
+        "icons",
+        "../packagesearch/app/icons",
+        "/usr/share/pixmaps/packagesearch"
+    };
+    _iconDir = searchFileInPathList(iconPaths, "packagesearch.png", "icon");
 }
 
 
@@ -1072,13 +1068,6 @@ void PackageSearchImpl::checkAptDbForUpdates()
 	_pApt->checkCacheUpdates();
 }
 
-
-void PackageSearchImpl::setTranslationDir(const QDir& dir) 
-{
-	_pPluginManager->setTranslationDir(dir);
-}
-
-
 void PackageSearchImpl::updateXapianDatabase() 
 {
 	setEnabled(false);
